Rename vpe binary name to avoid collision with latex

Change-Id: I34a46b9ebbc0e36486fbef528b34ea1c3be2e8be
Signed-off-by: Damjan Marion <damarion@cisco.com>
diff --git a/test/README b/test/README
index 862541a..40154bb 100644
--- a/test/README
+++ b/test/README
@@ -7,7 +7,7 @@
  - install python requirements for this project by executing:
     # pip install -r requirements.txt
  - make sure user mentioned in topology.py has NOPASSWD sudo access to
-    vpe_api_test
+    vpp_api_test
 
 
  Done.
diff --git a/test/resources/libraries/bash/dut_setup.sh b/test/resources/libraries/bash/dut_setup.sh
index c6cbd03..1da8cc9 100644
--- a/test/resources/libraries/bash/dut_setup.sh
+++ b/test/resources/libraries/bash/dut_setup.sh
@@ -1,7 +1,7 @@
 #!/bin/bash
 
-echo vpe process
-ps aux | grep vpe
+echo vpp process
+ps aux | grep vpp
 
 echo Free memory
 free -m
diff --git a/test/resources/libraries/python/VatExecutor.py b/test/resources/libraries/python/VatExecutor.py
index 55a0454..f10259b 100644
--- a/test/resources/libraries/python/VatExecutor.py
+++ b/test/resources/libraries/python/VatExecutor.py
@@ -19,7 +19,7 @@
 class VatExecutor(object):
     
     __TMP_DIR = "/tmp/"
-    __VAT_BIN = "vpe_api_test"
+    __VAT_BIN = "vpp_api_test"
 
     def __init__(self):
         self._stdout = None
@@ -53,7 +53,7 @@
         logger.trace("stdout: '{0}'".format(self._stdout))
         logger.trace("stderr: '{0}'".format(self._stderr))
 
         #TODO: download vpe_api_test output file
         self._delete_files(node, remote_file_path, remote_file_out)
 
     def _delete_files(self, node, *files):
@@ -53,7 +53,7 @@
         logger.trace("stderr: '{0}'".format(self._stderr))
 
-        #TODO: download vpe_api_test output file
+        #TODO: download vpp_api_test output file
         self._delete_files(node, remote_file_path, remote_file_out)
 